==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/Logger.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Project-level logging utilities.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.413Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Logger")
public class Logger extends io.github.cdklabs.projen.Component {

    protected Logger(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Logger(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Logger(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.LoggerOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Logger(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Log a message to stderr with DEBUG severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void debug(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "debug", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with ERROR severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void error(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "error", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with INFO severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void info(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "info", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with a given logging level.
     * <p>
     * The message will be
     * printed as long as <code>logger.level</code> is set to the message's severity or higher.
     * <p>
     * @param level Logging verbosity. This parameter is required.
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void log(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.LogLevel level, final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "log", software.amazon.jsii.NativeType.VOID, java.util.stream.Stream.concat(java.util.Arrays.<Object>stream(new Object[] { java.util.Objects.requireNonNull(level, "level is required") }), java.util.Arrays.<Object>stream(text)).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with VERBOSE severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void verbose(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "verbose", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with WARN severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void warn(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "warn", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.Logger}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.Logger> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.LoggerOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) The logging verbosity.
         * <p>
         * The levels available (in increasing verbosity) are
         * OFF, ERROR, WARN, INFO, DEBUG, and VERBOSE.
         * <p>
         * Default: LogLevel.INFO
         * <p>
         * @return {@code this}
         * @param level The logging verbosity. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder level(final io.github.cdklabs.projen.LogLevel level) {
            this.options().level(level);
            return this;
        }

        /**
         * (experimental) Include a prefix for all logging messages with the project name.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param usePrefix Include a prefix for all logging messages with the project name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder usePrefix(final java.lang.Boolean usePrefix) {
            this.options().usePrefix(usePrefix);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.Logger}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.Logger build() {
            return new io.github.cdklabs.projen.Logger(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.LoggerOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.LoggerOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/Logger.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Project-level logging utilities.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.119Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.Logger")
public class Logger extends io.github.cdklabs.projen.Component {

    protected Logger(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Logger(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Logger(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.LoggerOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), options });
    }

    /**
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Logger(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * (experimental) Log a message to stderr with DEBUG severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void debug(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "debug", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with ERROR severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void error(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "error", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with INFO severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void info(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "info", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with a given logging level.
     * <p>
     * The message will be
     * printed as long as <code>logger.level</code> is set to the message's severity or higher.
     * <p>
     * @param level Logging verbosity. This parameter is required.
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void log(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.LogLevel level, final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "log", software.amazon.jsii.NativeType.VOID, java.util.stream.Stream.concat(java.util.Arrays.<Object>stream(new Object[] { java.util.Objects.requireNonNull(level, "level is required") }), java.util.Arrays.<Object>stream(text)).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with VERBOSE severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void verbose(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "verbose", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) Log a message to stderr with WARN severity.
     * <p>
     * @param text strings or objects to print. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void warn(final @org.jetbrains.annotations.NotNull java.lang.Object... text) {
        software.amazon.jsii.Kernel.call(this, "warn", software.amazon.jsii.NativeType.VOID, java.util.Arrays.<Object>stream(text).toArray(Object[]::new));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.Logger}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.Logger> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.IConstruct scope) {
            return new Builder(scope);
        }

        private final software.constructs.IConstruct scope;
        private io.github.cdklabs.projen.LoggerOptions.Builder options;

        private Builder(final software.constructs.IConstruct scope) {
            this.scope = scope;
        }

        /**
         * (experimental) The logging verbosity.
         * <p>
         * The levels available (in increasing verbosity) are
         * OFF, ERROR, WARN, INFO, DEBUG, and VERBOSE.
         * <p>
         * Default: LogLevel.INFO
         * <p>
         * @return {@code this}
         * @param level The logging verbosity. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder level(final io.github.cdklabs.projen.LogLevel level) {
            this.options().level(level);
            return this;
        }

        /**
         * (experimental) Include a prefix for all logging messages with the project name.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param usePrefix Include a prefix for all logging messages with the project name. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder usePrefix(final java.lang.Boolean usePrefix) {
            this.options().usePrefix(usePrefix);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.Logger}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.Logger build() {
            return new io.github.cdklabs.projen.Logger(
                this.scope,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.LoggerOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.LoggerOptions.Builder();
            }
            return this.options;
        }
    }
}
